==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/event/impl/EventSpecificationStatementSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.event.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.body.ACT_SMTSet;
import io.ciera.tool.sql.ooaofooa.body.impl.ACT_SMTSetImpl;
import io.ciera.tool.sql.ooaofooa.event.CreateEventStatementSet;
import io.ciera.tool.sql.ooaofooa.event.EventSpecificationStatement;
import io.ciera.tool.sql.ooaofooa.event.EventSpecificationStatementSet;
import io.ciera.tool.sql.ooaofooa.event.GenerateEventStatementSet;
import io.ciera.tool.sql.ooaofooa.event.impl.CreateEventStatementSetImpl;
import io.ciera.tool.sql.ooaofooa.event.impl.GenerateEventStatementSetImpl;
import io.ciera.tool.sql.ooaofooa.value.V_PARSet;
import io.ciera.tool.sql.ooaofooa.value.impl.V_PARSetImpl;

import java.util.Arrays;
import java.util.List;


public class EventSpecificationStatementSetImpl extends InstanceSet<EventSpecificationStatementSet,EventSpecificationStatement> implements EventSpecificationStatementSet {

    // attributes
    @Override
    public void setStatement_ID( UniqueId ref_Statement_ID ) throws XtumlException {
        for ( EventSpecificationStatement eventspecificationstatement : this ) eventspecificationstatement.setStatement_ID( ref_Statement_ID );
    }
    @Override
    public void setEventMeaningColumn( int m_eventMeaningColumn ) throws XtumlException {
        for ( EventSpecificationStatement eventspecificationstatement : this ) eventspecificationstatement.setEventMeaningColumn( m_eventMeaningColumn );
    }
    @Override
    public void setCurrentLaterEventDataItemNameLineNumber( int m_currentLaterEventDataItemNameLineNumber ) throws XtumlException {
        for ( EventSpecificationStatement eventspecificationstatement : this ) eventspecificationstatement.setCurrentLaterEventDataItemNameLineNumber( m_currentLaterEventDataItemNameLineNumber );
    }
    @Override
    public void setEventDerivedLabelLineNumber( int m_eventDerivedLabelLineNumber ) throws XtumlException {
        for ( EventSpecificationStatement eventspecificationstatement : this ) eventspecificationstatement.setEventDerivedLabelLineNumber( m_eventDerivedLabelLineNumber );
    }
    @Override
    public void setFirstEventDataItemNameColumn( int m_firstEventDataItemNameColumn ) throws XtumlException {
        for ( EventSpecificationStatement eventspecificationstatement : this ) eventspecificationstatement.setFirstEventDataItemNameColumn( m_firstEventDataItemNameColumn );
    }
    @Override
    public void setEventDerivedLabelColumn( int m_eventDerivedLabelColumn ) throws XtumlException {
        for ( EventSpecificationStatement eventspecificationstatement : this ) eventspecificationstatement.setEventDerivedLabelColumn( m_eventDerivedLabelColumn );
    }
    @Override
    public void setFirstEventDataItemNameLineNumber( int m_firstEventDataItemNameLineNumber ) throws XtumlException {
        for ( EventSpecificationStatement eventspecificationstatement : this ) eventspecificationstatement.setFirstEventDataItemNameLineNumber( m_firstEventDataItemNameLineNumber );
    }
    @Override
    public void setParmListOK( boolean m_ParmListOK ) throws XtumlException {
        for ( EventSpecificationStatement eventspecificationstatement : this ) eventspecificationstatement.setParmListOK( m_ParmListOK );
    }
    @Override
    public void setPEIndicated( boolean m_PEIndicated ) throws XtumlException {
        for ( EventSpecificationStatement eventspecificationstatement : this ) eventspecificationstatement.setPEIndicated( m_PEIndicated );
    }
    @Override
    public void setCurrentLaterEventDataItemNameColumn( int m_currentLaterEventDataItemNameColumn ) throws XtumlException {
        for ( EventSpecificationStatement eventspecificationstatement : this ) eventspecificationstatement.setCurrentLaterEventDataItemNameColumn( m_currentLaterEventDataItemNameColumn );
    }
    @Override
    public void setEventTargetKeyLettersColumn( int m_eventTargetKeyLettersColumn ) throws XtumlException {
        for ( EventSpecificationStatement eventspecificationstatement : this ) eventspecificationstatement.setEventTargetKeyLettersColumn( m_eventTargetKeyLettersColumn );
    }
    @Override
    public void setEventTargetKeyLettersLineNumber( int m_eventTargetKeyLettersLineNumber ) throws XtumlException {
        for ( EventSpecificationStatement eventspecificationstatement : this ) eventspecificationstatement.setEventTargetKeyLettersLineNumber( m_eventTargetKeyLettersLineNumber );
    }
    @Override
    public void setEventMeaningLineNumber( int m_eventMeaningLineNumber ) throws XtumlException {
        for ( EventSpecificationStatement eventspecificationstatement : this ) eventspecificationstatement.setEventMeaningLineNumber( m_eventMeaningLineNumber );
    }


    // selections
    @Override
    public ACT_SMTSet R603_is_a_ACT_SMT() throws XtumlException {
        ACT_SMTSet act_smtset = new ACT_SMTSetImpl();
        for ( EventSpecificationStatement eventspecificationstatement : this ) act_smtset.add( eventspecificationstatement.R603_is_a_ACT_SMT() );
        return act_smtset;
    }
    @Override
    public V_PARSet R700_V_PAR() throws XtumlException {
        V_PARSet v_parset = new V_PARSetImpl();
        for ( EventSpecificationStatement eventspecificationstatement : this ) v_parset.addAll( eventspecificationstatement.R700_V_PAR() );
        return v_parset;
    }
    @Override
    public CreateEventStatementSet R701_is_a_CreateEventStatement() throws XtumlException {
        CreateEventStatementSet createeventstatementset = new CreateEventStatementSetImpl();
        for ( EventSpecificationStatement eventspecificationstatement : this ) createeventstatementset.add( eventspecificationstatement.R701_is_a_CreateEventStatement() );
        return createeventstatementset;
    }
    @Override
    public GenerateEventStatementSet R701_is_a_GenerateEventStatement() throws XtumlException {
        GenerateEventStatementSet generateeventstatementset = new GenerateEventStatementSetImpl();
        for ( EventSpecificationStatement eventspecificationstatement : this ) generateeventstatementset.add( eventspecificationstatement.R701_is_a_GenerateEventStatement() );
        return generateeventstatementset;
    }


    @Override
    public EventSpecificationStatement nullElement() {
        return EventSpecificationStatementImpl.EMPTY_EVENTSPECIFICATIONSTATEMENT;
    }

    @Override
    public EventSpecificationStatementSet emptySet() {
      return new EventSpecificationStatementSetImpl();
    }

    @Override
    public EventSpecificationStatementSet value() {
        return this;
    }

    @Override
    public List<EventSpecificationStatement> elements() {
        return Arrays.asList(toArray(new EventSpecificationStatement[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/event/impl/EventSpecificationStatementSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.event.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.body.ACT_SMTSet;
import io.ciera.tool.sql.ooaofooa.body.impl.ACT_SMTSetImpl;
import io.ciera.tool.sql.ooaofooa.event.CreateEventStatementSet;
import io.ciera.tool.sql.ooaofooa.event.EventSpecificationStatement;
import io.ciera.tool.sql.ooaofooa.event.EventSpecificationStatementSet;
import io.ciera.tool.sql.ooaofooa.event.GenerateEventStatementSet;
import io.ciera.tool.sql.ooaofooa.event.impl.CreateEventStatementSetImpl;
import io.ciera.tool.sql.ooaofooa.event.impl.GenerateEventStatementSetImpl;
import io.ciera.tool.sql.ooaofooa.value.V_PARSet;
import io.ciera.tool.sql.ooaofooa.value.impl.V_PARSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class EventSpecificationStatementSetImpl extends InstanceSet<EventSpecificationStatementSet,EventSpecificationStatement> implements EventSpecificationStatementSet {

    public EventSpecificationStatementSetImpl() {
    }

    public EventSpecificationStatementSetImpl(Comparator<? super EventSpecificationStatement> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setEventTargetKeyLettersLineNumber( int m_eventTargetKeyLettersLineNumber ) throws XtumlException {
        for ( EventSpecificationStatement eventspecificationstatement : this ) eventspecificationstatement.setEventTargetKeyLettersLineNumber( m_eventTargetKeyLettersLineNumber );
    }
    @Override
    public void setEventDerivedLabelColumn( int m_eventDerivedLabelColumn ) throws XtumlException {
        for ( EventSpecificationStatement eventspecificationstatement : this ) eventspecificationstatement.setEventDerivedLabelColumn( m_eventDerivedLabelColumn );
    }
    @Override
    public void setParmListOK( boolean m_ParmListOK ) throws XtumlException {
        for ( EventSpecificationStatement eventspecificationstatement : this ) eventspecificationstatement.setParmListOK( m_ParmListOK );
    }
    @Override
    public void setEventMeaningColumn( int m_eventMeaningColumn ) throws XtumlException {
        for ( EventSpecificationStatement eventspecificationstatement : this ) eventspecificationstatement.setEventMeaningColumn( m_eventMeaningColumn );
    }
    @Override
    public void setPEIndicated( boolean m_PEIndicated ) throws XtumlException {
        for ( EventSpecificationStatement eventspecificationstatement : this ) eventspecificationstatement.setPEIndicated( m_PEIndicated );
    }
    @Override
    public void setCurrentLaterEventDataItemNameLineNumber( int m_currentLaterEventDataItemNameLineNumber ) throws XtumlException {
        for ( EventSpecificationStatement eventspecificationstatement : this ) eventspecificationstatement.setCurrentLaterEventDataItemNameLineNumber( m_currentLaterEventDataItemNameLineNumber );
    }
    @Override
    public void setStatement_ID( UniqueId ref_Statement_ID ) throws XtumlException {
        for ( EventSpecificationStatement eventspecificationstatement : this ) eventspecificationstatement.setStatement_ID( ref_Statement_ID );
    }
    @Override
    public void setCurrentLaterEventDataItemNameColumn( int m_currentLaterEventDataItemNameColumn ) throws XtumlException {
        for ( EventSpecificationStatement eventspecificationstatement : this ) eventspecificationstatement.setCurrentLaterEventDataItemNameColumn( m_currentLaterEventDataItemNameColumn );
    }
    @Override
    public void setFirstEventDataItemNameColumn( int m_firstEventDataItemNameColumn ) throws XtumlException {
        for ( EventSpecificationStatement eventspecificationstatement : this ) eventspecificationstatement.setFirstEventDataItemNameColumn( m_firstEventDataItemNameColumn );
    }
    @Override
    public void setEventMeaningLineNumber( int m_eventMeaningLineNumber ) throws XtumlException {
        for ( EventSpecificationStatement eventspecificationstatement : this ) eventspecificationstatement.setEventMeaningLineNumber( m_eventMeaningLineNumber );
    }
    @Override
    public void setEventTargetKeyLettersColumn( int m_eventTargetKeyLettersColumn ) throws XtumlException {
        for ( EventSpecificationStatement eventspecificationstatement : this ) eventspecificationstatement.setEventTargetKeyLettersColumn( m_eventTargetKeyLettersColumn );
    }
    @Override
    public void setFirstEventDataItemNameLineNumber( int m_firstEventDataItemNameLineNumber ) throws XtumlException {
        for ( EventSpecificationStatement eventspecificationstatement : this ) eventspecificationstatement.setFirstEventDataItemNameLineNumber( m_firstEventDataItemNameLineNumber );
    }
    @Override
    public void setEventDerivedLabelLineNumber( int m_eventDerivedLabelLineNumber ) throws XtumlException {
        for ( EventSpecificationStatement eventspecificationstatement : this ) eventspecificationstatement.setEventDerivedLabelLineNumber( m_eventDerivedLabelLineNumber );
    }


    // selections
    @Override
    public ACT_SMTSet R603_is_a_ACT_SMT() throws XtumlException {
        ACT_SMTSet act_smtset = new ACT_SMTSetImpl();
        for ( EventSpecificationStatement eventspecificationstatement : this ) act_smtset.add( eventspecificationstatement.R603_is_a_ACT_SMT() );
        return act_smtset;
    }
    @Override
    public V_PARSet R700_V_PAR() throws XtumlException {
        V_PARSet v_parset = new V_PARSetImpl();
        for ( EventSpecificationStatement eventspecificationstatement : this ) v_parset.addAll( eventspecificationstatement.R700_V_PAR() );
        return v_parset;
    }
    @Override
    public CreateEventStatementSet R701_is_a_CreateEventStatement() throws XtumlException {
        CreateEventStatementSet createeventstatementset = new CreateEventStatementSetImpl();
        for ( EventSpecificationStatement eventspecificationstatement : this ) createeventstatementset.add( eventspecificationstatement.R701_is_a_CreateEventStatement() );
        return createeventstatementset;
    }
    @Override
    public GenerateEventStatementSet R701_is_a_GenerateEventStatement() throws XtumlException {
        GenerateEventStatementSet generateeventstatementset = new GenerateEventStatementSetImpl();
        for ( EventSpecificationStatement eventspecificationstatement : this ) generateeventstatementset.add( eventspecificationstatement.R701_is_a_GenerateEventStatement() );
        return generateeventstatementset;
    }


    @Override
    public EventSpecificationStatement nullElement() {
        return EventSpecificationStatementImpl.EMPTY_EVENTSPECIFICATIONSTATEMENT;
    }

    @Override
    public EventSpecificationStatementSet emptySet() {
      return new EventSpecificationStatementSetImpl();
    }

    @Override
    public EventSpecificationStatementSet emptySet(Comparator<? super EventSpecificationStatement> comp) {
      return new EventSpecificationStatementSetImpl(comp);
    }

    @Override
    public EventSpecificationStatementSet value() {
        return this;
    }

    @Override
    public List<EventSpecificationStatement> elements() {
        return Arrays.asList(toArray(new EventSpecificationStatement[0]));
    }

}
